@@ -12,15 +12,16 @@
 
 from lollypop.art_base import BaseArt
 from lollypop.art_album import AlbumArt
+from lollypop.art_artist import ArtistArt
 from lollypop.art_radio import RadioArt
 from lollypop.logger import Logger
-from lollypop.downloader import Downloader
+from lollypop.downloader_art import ArtDownloader
 from lollypop.utils import create_dir
 
 from shutil import rmtree
 
 
-class Art(BaseArt, AlbumArt, RadioArt, Downloader):
+class Art(BaseArt, AlbumArt, ArtistArt, RadioArt, ArtDownloader):
     """
         Global artwork manager
     """
@@ -31,8 +32,9 @@ class Art(BaseArt, AlbumArt, RadioArt, Downloader):
         """
         BaseArt.__init__(self)
         AlbumArt.__init__(self)
+        ArtistArt.__init__(self)
         RadioArt.__init__(self)
-        Downloader.__init__(self)
+        ArtDownloader.__init__(self)
         create_dir(self._CACHE_PATH)
         create_dir(self._STORE_PATH)
         create_dir(self._WEB_PATH)
@@ -51,7 +53,8 @@ class Art(BaseArt, AlbumArt, RadioArt, Downloader):
             Remove all covers from cache
         """
         try:
-            rmtree(self._CACHE_PATH)
-            create_dir(self._CACHE_PATH)
+            from pathlib import Path
+            for p in Path(self._CACHE_PATH).glob("*.jpg"):
+                p.unlink()
         except Exception as e:
             Logger.error("Art::clean_all_cache(): %s", e)
